@@ -39,7 +39,7 @@
 #define TTY int			/* FIXME: TTY originalMode */
 #include <curses.priv.h>
 
-MODULE_ID("$Id: lib_win32con.c,v 1.42 2025/10/04 18:19:06 tom Exp $")
+MODULE_ID("$Id: lib_win32con.c,v 1.44 2025/11/29 21:45:49 tom Exp $")
 
 #if defined(_NC_WINDOWS)
 
@@ -83,7 +83,7 @@ static const LONG ansi_keys[] =
 
 static bool console_initialized = FALSE;
 
-#if defined(EXP_WIN32_DRIVER)
+#if defined(_NC_WINDOWS)
 /*   A process can only have a single console, so it is safe
      to maintain all the information about it in a single
      static structure.
@@ -225,9 +225,6 @@ _nc_console_fd2handle(int fd)
 	T(("lib_win32con:validateHandle %d maps to unknown HANDLE", fd));
 	hdl = INVALID_HANDLE_VALUE;
     }
-#if 1
-    assert(hdl != INVALID_HANDLE_VALUE);
-#endif
     if (hdl != INVALID_HANDLE_VALUE) {
 	if (hdl != WINCONSOLE.inp && (!WINCONSOLE.isTermInfoConsole && WINCONSOLE.progMode)) {
 	    if (hdl == WINCONSOLE.out && hdl != WINCONSOLE.hdl) {
@@ -239,7 +236,7 @@ _nc_console_fd2handle(int fd)
     return hdl;
 }
 
-#if defined(EXP_WIN32_DRIVER)
+#if defined(_NC_WINDOWS)
 NCURSES_EXPORT(int)
 _nc_console_setmode(HANDLE hdl, const TTY * arg)
 {
@@ -389,7 +386,7 @@ save_original_screen(void)
     return result;
 }
 
-#if defined(EXP_WIN32_DRIVER)
+#if defined(_NC_WINDOWS)
 static bool
 restore_original_screen(void)
 {
@@ -1114,7 +1111,6 @@ _nc_console_isatty(int fd)
     returnCode(result);
 }
 
-#if defined(EXP_WIN32_DRIVER)
 NCURSES_EXPORT(bool)
 _nc_console_checkinit(bool initFlag, bool assumeTermInfo)
 {
@@ -1267,7 +1263,7 @@ _nc_console_restore(void)
     returnBool(res);
 }
 
-#else // !defined(EXP_WIN32_DRIVER)
+#if !defined(EXP_WIN32_DRIVER)
 NCURSES_EXPORT(bool)
 _nc_mingw_init(void)
 {
